@@ -9,7 +9,7 @@ class Field:
     def make_obj(self, value, instance):
         if self.parent is list:
             if self.two_dim:
-                return [ [self.cls(obj) for obj in item_list] for item_list in value ]
+                return [ [self.cls(**obj) for obj in item_list] for item_list in value ]
             else:
                 return [self.cls(obj) for obj in value] if self.cls else value
 
